pub struct Committee { /* private fields */ }Expand description
Committee is the set of authorities that participate in the consensus protocol for this epoch. Its configuration is stored and computed on chain.
Implementations
Sourceimpl Committee
impl Committee
pub fn new(epoch: Epoch, authorities: Vec<Authority>) -> Self
Sourcepub fn new_v3(
epoch: Epoch,
authorities: Vec<Authority>,
malicious_stake: Stake,
crash_stake: Stake,
) -> Self
pub fn new_v3( epoch: Epoch, authorities: Vec<Authority>, malicious_stake: Stake, crash_stake: Stake, ) -> Self
Constructs a committee with thresholds derived from a hybrid fault budget
(malicious_stake = f, crash_stake = c).
Nominally, the total stake is nominal_total_stake = 5f + 3c + 1;
and the thresholds evaluate to:
validity_threshold = f + 1certification_threshold = 2f + c + 1quorum_threshold = 4f + 2c + 1
But the actual total stakes specified by the authorities may differ
from the nominal total stake computed above. We will scale f and c
from the nominal value to the largest possible values where intersection
properties still hold. Then the thresholds are computed with scaled f and c.
pub fn epoch(&self) -> Epoch
pub fn total_stake(&self) -> Stake
pub fn quorum_threshold(&self) -> Stake
pub fn certification_threshold(&self) -> Stake
pub fn validity_threshold(&self) -> Stake
pub fn stake(&self, authority_index: AuthorityIndex) -> Stake
Returns the authorities as a slice, preserving their order (and hence
their AuthorityIndex values). Useful for rebuilding a Committee with
different threshold parameters while keeping the same authority set.
Sourcepub fn reached_quorum(&self, stake: Stake) -> bool
pub fn reached_quorum(&self, stake: Stake) -> bool
Returns true if the provided stake has reached quorum (2f+1).
Sourcepub fn reached_validity(&self, stake: Stake) -> bool
pub fn reached_validity(&self, stake: Stake) -> bool
Returns true if the provided stake has reached validity (f+1).
Converts an index to an AuthorityIndex, if valid. Returns None if index is out of bound.
Sourcepub fn is_valid_index(&self, index: AuthorityIndex) -> bool
pub fn is_valid_index(&self, index: AuthorityIndex) -> bool
Returns true if the provided index is valid.