pub struct ObserverParameters {
pub server_port: Option<u16>,
pub allowlist: Vec<String>,
pub quorum_release: bool,
pub peers: Vec<PeerRecord>,
}Expand description
Observer node configuration parameters.
Fields
server_port: Option<u16>Port for the observer server. If configured, then the node will run the observer server on this port.
If unspecified, this will default to None.
allowlist: Vec<String>Allowlist of observer public keys (hex encoded). If empty, all observers are allowed. If non-empty, only observers with these public keys will be allowed to connect.
If unspecified, this will default to an empty Vec (no allowlist, all observers allowed).
quorum_release: boolWhether the observer server buffers accepted blocks and releases them to observers only once a quorum of blocks for their round has been gathered (or the release timeout expires). When disabled, blocks are served to observers as soon as they are accepted.
If unspecified, this will default to true.
peers: Vec<PeerRecord>List of observer peers to connect to when acting as an observer client. Each record contains the network public key and multi-address of a peer observer server.
If unspecified, this will default to an empty Vec.
Implementations
Sourceimpl ObserverParameters
impl ObserverParameters
pub fn is_server_enabled(&self) -> bool