pub struct TonicParameters {
pub keepalive_interval: Duration,
pub connection_buffer_size: usize,
pub excessive_message_size: usize,
pub message_size_limit: usize,
pub observer_server_port: Option<u16>,
pub observer_allowlist: Vec<String>,
}Fields
keepalive_interval: DurationKeepalive interval and timeouts for both client and server.
If unspecified, this will default to 5s.
connection_buffer_size: usizeSize of various per-connection buffers.
If unspecified, this will default to 32MiB.
excessive_message_size: usizeMessages over this size threshold will increment a counter.
If unspecified, this will default to 16MiB.
message_size_limit: usizeHard message size limit for both requests and responses. This value is higher than strictly necessary, to allow overheads. Message size targets and soft limits are computed based on this value.
If unspecified, this will default to 1GiB.
observer_server_port: Option<u16>Port for the observer server. If configured, then the node will run the observer server on this port.
If unspecified, this will default to None.
observer_allowlist: Vec<String>Allowlist of observer public keys (hex encoded). If empty, all observers are allowed. If non-empty, only observers with these public keys will be allowed to connect.
If unspecified, this will default to an empty Vec (no allowlist, all observers allowed).
Implementations
Sourceimpl TonicParameters
impl TonicParameters
pub fn is_observer_server_enabled(&self) -> bool